@@ -255,19 +255,19 @@ PERSISTENT_OPTIONS = (
     ('date-format',
      {'type' : 'string',
       'default': '%Y/%m/%d',
-      'help': _('how to format date in the ui ("man strftime" for format description)'),
+      'help': _('how to format date in the ui (see <a href="http://docs.python.org/library/datetime.html#strftime-strptime-behavior">this page</a> for format description)'),
       'group': 'ui',
       }),
     ('datetime-format',
      {'type' : 'string',
       'default': '%Y/%m/%d %H:%M',
-      'help': _('how to format date and time in the ui ("man strftime" for format description)'),
+      'help': _('how to format date and time in the ui (see <a href="http://docs.python.org/library/datetime.html#strftime-strptime-behavior">this page</a> for format description)'),
       'group': 'ui',
       }),
     ('time-format',
      {'type' : 'string',
       'default': '%H:%M',
-      'help': _('how to format time in the ui ("man strftime" for format description)'),
+      'help': _('how to format time in the ui (see <a href="http://docs.python.org/library/datetime.html#strftime-strptime-behavior">this page</a> for format description)'),
       'group': 'ui',
       }),
     ('float-format',
@@ -1149,7 +1149,7 @@ the repository',
 
     def _gettext_init(self):
         """set language for gettext"""
-        from gettext import translation
+        from cubicweb.gettext import translation
         path = join(self.apphome, 'i18n')
         for language in self.available_languages():
             self.info("loading language %s", language)
