@@ -300,6 +300,9 @@ class CWETypeRenameOp(MemSchemaOperation):
         self.info('renamed table %s to %s', oldname, newname)
         sqlexec('UPDATE entities SET type=%(newname)s WHERE type=%(oldname)s',
                 {'newname': newname, 'oldname': oldname})
+        for eid, (etype, uri, extid, auri) in self.session.repo._type_source_cache.items():
+            if etype == oldname:
+                self.session.repo._type_source_cache[eid] = (newname, uri, extid, auri)
         sqlexec('UPDATE deleted_entities SET type=%(newname)s WHERE type=%(oldname)s',
                 {'newname': newname, 'oldname': oldname})
         # XXX transaction records
@@ -484,6 +487,11 @@ class CWAttributeAddOp(MemSchemaOperation):
         # set default value, using sql for performance and to avoid
         # modification_date update
         if default:
+            if  rdefdef.object in ('Date', 'Datetime'):
+                if default == 'TODAY':
+                    default = syssource.dbhelper.sql_current_date()
+                elif default == 'NOW':
+                    default = syssource.dbhelper.sql_current_timestamp()
             session.system_sql('UPDATE %s SET %s=%%(default)s' % (table, column),
                                {'default': default})
 
