@@ -168,6 +168,6 @@ errorMsgColor = '#ed0d0d'
 
 # facets
 facet_titleFont = 'bold SansSerif'
-facet_overflowedHeight = '12em'
-# the above minus 1
-facet_overflowedHeightWithLogicalSelector = '11em'
+facet_Padding = '.4em'
+facet_MarginBottom = '.4em'
+facet_vocabMaxHeight = '12em' # ensure < FACET_GROUP_HEIGHT by some const. factor (e.g 3em)
