@@ -349,8 +349,10 @@ class JSonController(Controller):
             if vtitle:
                 stream.write(u'<h1 class="vtitle">%s</h1>\n' % vtitle)
             paginate = True
+        nav_html = UStringIO()
         if paginate and not view.handle_pagination:
-            view.paginate()
+            view.paginate(w=nav_html.write)
+        stream.write(nav_html.getvalue())
         if divid == 'pageContent':
             stream.write(u'<div id="contentmain">')
         view.render(**kwargs)
@@ -360,7 +362,7 @@ class JSonController(Controller):
             stream.write(extresources)
             stream.write(u'</div>\n')
         if divid == 'pageContent':
-            stream.write(u'</div></div>')
+            stream.write(u'</div>%s</div>' % nav_html.getvalue())
         return stream.getvalue()
 
     @xhtmlize
@@ -578,12 +580,11 @@ class MailBugReportController(Controller):
     __select__ = match_form_params('description')
 
     def publish(self, rset=None):
-        body = self._cw.form['description']
-        self.sendmail(self._cw.config['submit-mail'],
-                      self._cw._('%s error report') % self._cw.config.appid,
-                      body)
-        url = self._cw.build_url(__message=self._cw._('bug report sent'))
-        raise Redirect(url)
+        req = self._cw
+        self.sendmail(req.vreg.config['submit-mail'],
+                      req._('%s error report') % req.vreg.config.appid,
+                      req.form['description'])
+        raise Redirect(req.build_url(__message=req._('bug report sent')))
 
 
 class UndoController(Controller):
