@@ -177,7 +177,7 @@ class TableLayout(component.Component):
         or from subsequent calls by the form filter or by the pagination hooks.
         """
         form = self._cw.form
-        return 'fromformfilter' not in form and '__start' not in form
+        return 'fromformfilter' not in form and '__fromnavigation' not in form
 
     def render(self, w, **kwargs):
         assert self.display_filter in (None, 'top', 'bottom'), self.display_filter
@@ -289,9 +289,8 @@ class TableLayout(component.Component):
         return attrs
 
     def render_actions(self, w, actions):
-        box = MenuWidget('', 'tableActionsBox', _class='', islist=False)
-        label = tags.img(src=self._cw.uiprops['PUCE_DOWN'],
-                         alt=xml_escape(self._cw._('action(s) on this selection')))
+        box = MenuWidget('', '', _class='tableActionsBox', islist=False)
+        label = tags.span(self._cw._('action menu'))
         menu = PopupBoxMenu(label, isitem=False, link_class='actionsBox',
                             ident='%sActions' % self.view.domid)
         box.append(menu)
@@ -782,7 +781,11 @@ class MainEntityColRenderer(EntityTableColRenderer):
 
     def default_header(self):
         view = self.view
-        return u', '.join(self._cw.__(et+'_plural')
+        if len(view.cw_rset) > 1:
+            suffix = '_plural'
+        else:
+            suffix = ''
+        return u', '.join(self._cw.__(et + suffix)
                           for et in view.cw_rset.column_types(view.cw_col or 0))
 
     def render_entity(self, w, entity):
@@ -819,24 +822,39 @@ class RelationColRenderer(EntityTableColRenderer):
     considered as the subject of the relation but you may specify otherwise
     using the `role` argument.
 
-    By default display the related rset using the 'csv' view and 'outofcontext'
-    view for each entity. You may specify another view identifier using
-    respectivly the `vid` and `subvid` arguments.
+    By default display the related rset using the 'csv' view, using
+    'outofcontext' sub-view for each entity. You may specify another view
+    identifier using respectivly the `vid` and `subvid` arguments.
+
+    If you specify a 'rtype view', such as 'reledit', you should add a
+    is_rtype_view=True parameter.
 
     If header not specified, it would be built by translating the column id,
     properly considering role.
     """
-    def __init__(self, role='subject', vid='csv', subvid='outofcontext',
-                 fallbackvid='empty-cell', **kwargs):
+    def __init__(self, role='subject', vid='csv', subvid=None,
+                 fallbackvid='empty-cell', is_rtype_view=False, **kwargs):
         super(RelationColRenderer, self).__init__(**kwargs)
         self.role = role
         self.vid = vid
+        if subvid is None and vid in ('csv', 'list'):
+            subvid = 'outofcontext'
         self.subvid = subvid
         self.fallbackvid = fallbackvid
+        self.is_rtype_view = is_rtype_view
 
     def render_entity(self, w, entity):
-        self._cw.view(self.vid, entity.related(self.colid, self.role),
-                      self.fallbackvid, subvid=self.subvid, w=w)
+        kwargs = {'w': w}
+        if self.is_rtype_view:
+            rset = None
+            kwargs['entity'] = entity
+            kwargs['rtype'] = self.colid
+            kwargs['role'] = self.role
+        else:
+            rset = entity.related(self.colid, self.role)
+        if self.subvid is not None:
+            kwargs['subvid'] = self.subvid
+        self._cw.view(self.vid, rset, self.fallbackvid, **kwargs)
 
     def default_header(self):
         return display_name(self._cw, self.colid, self.role)
