@@ -20,6 +20,7 @@
 import re
 
 from cubicweb import typed_eid
+from cubicweb.uilib import domid
 from cubicweb.appobject import AppObject
 
 
@@ -96,8 +97,11 @@ class SimpleReqRewriter(URLRewriter):
         ('/error', dict(vid='error')),
         ('/sparql', dict(vid='sparql')),
         ('/processinfo', dict(vid='processinfo')),
-        (rgx('/cwuser', re.I), dict(vid='cw.user-management')),
-        (rgx('/cwsource', re.I), dict(vid='cw.source-management')),
+        (rgx('/cwuser', re.I), dict(vid='cw.users-and-groups-management',
+                                    tab=domid('cw.users-management'))),
+        (rgx('/cwgroup', re.I), dict(vid='cw.users-and-groups-management',
+                                     tab=domid('cw.groups-management'))),
+        (rgx('/cwsource', re.I), dict(vid='cw.sources-management')),
         # XXX should be case insensitive as 'create', but I would like to find another way than
         # relying on the etype_selector
         (rgx('/schema/([^/]+?)/?'),  dict(vid='primary', rql=r'Any X WHERE X is CWEType, X name "\1"')),
